from setuptools import setup

setup(
    name='navalmartin_mir_vision_utils',
    packages=['navalmartin_mir_vision_utils'],
    version='0.0.1',
    description='Various utilities for working with images in the mir project.',
    author='Alexandros Giavaras',
    author_email='a.giavaras@gmail.com',
    url='https://github.com/Navalmartin/navalmartin_mir_vision_utils',
    download_url='https://github.com/pockerman/awsutils/awsutils-0.0.3.tar.gz',
    keywords=['images', 'computer-vision'],
    classifiers=[],
    scripts=[],
)
